/*
 * SPDX-FileCopyrightText: 2020 Stalwart Labs Ltd <hello@stalw.art>
 *
 * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
 */

pub mod bayes;
pub mod body;
pub mod copy;
pub mod crypto;
pub mod delete;
pub mod get;
pub mod headers;
pub mod import;
pub mod parse;
pub mod query;
pub mod set;
pub mod snippet;
